Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1362)

Unified Diff: content/browser/frame_host/frame_tree_browsertest.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/frame_tree_browsertest.cc
diff --git a/content/browser/frame_host/frame_tree_browsertest.cc b/content/browser/frame_host/frame_tree_browsertest.cc
index 459f3caa68086db65e160cba02db1fb4d3f58a90..5526675ba49e2add525464e254f729909cb97e42 100644
--- a/content/browser/frame_host/frame_tree_browsertest.cc
+++ b/content/browser/frame_host/frame_tree_browsertest.cc
@@ -274,10 +274,10 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, OriginSetOnNavigation) {
GURL data_url("data:text/html,foo");
EXPECT_TRUE(NavigateToURL(shell(), data_url));
// Navigating to a data URL should set a unique origin. This is represented
// as "null" per RFC 6454.
EXPECT_EQ("null", root->current_origin().Serialize());
- EXPECT_TRUE(contents->GetMainFrame()->GetLastCommittedOrigin().unique());
+ EXPECT_TRUE(contents->GetMainFrame()->GetLastCommittedOrigin().opaque());
EXPECT_EQ("null", GetOriginFromRenderer(root));
// Re-navigating to a normal URL should update the origin.
@@ -287,7 +287,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, OriginSetOnNavigation) {
EXPECT_EQ(
main_url.GetOrigin().spec(),
contents->GetMainFrame()->GetLastCommittedOrigin().Serialize() + '/');
- EXPECT_FALSE(contents->GetMainFrame()->GetLastCommittedOrigin().unique());
+ EXPECT_FALSE(contents->GetMainFrame()->GetLastCommittedOrigin().opaque());
EXPECT_EQ(root->current_origin().Serialize(), GetOriginFromRenderer(root));
}
@@ -334,7 +334,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, NavigateGrandchildToBlob) {
deleted_observer.WaitUntilDeleted();
EXPECT_EQ(GURL(blob_url_string), target->current_url());
EXPECT_EQ(url::kBlobScheme, target->current_url().scheme());
- EXPECT_FALSE(target->current_origin().unique());
+ EXPECT_FALSE(target->current_origin().opaque());
EXPECT_EQ("a.com", target->current_origin().host());
EXPECT_EQ(url::kHttpScheme, target->current_origin().scheme());
@@ -383,7 +383,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, NavigateChildToAboutBlank) {
&about_blank_origin));
EXPECT_EQ(GURL(url::kAboutBlankURL), target->current_url());
EXPECT_EQ(url::kAboutScheme, target->current_url().scheme());
- EXPECT_FALSE(target->current_origin().unique());
+ EXPECT_FALSE(target->current_origin().opaque());
EXPECT_EQ("b.com", target->current_origin().host());
EXPECT_EQ(url::kHttpScheme, target->current_origin().scheme());
EXPECT_EQ(target->current_origin().Serialize(), about_blank_origin);
@@ -433,7 +433,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest,
&about_blank_origin));
EXPECT_EQ(GURL(url::kAboutBlankURL), target->current_url());
EXPECT_EQ(url::kAboutScheme, target->current_url().scheme());
- EXPECT_FALSE(target->current_origin().unique());
+ EXPECT_FALSE(target->current_origin().opaque());
EXPECT_EQ("a.com", target->current_origin().host());
EXPECT_EQ(url::kHttpScheme, target->current_origin().scheme());
EXPECT_EQ(target->current_origin().Serialize(), about_blank_origin);
@@ -531,7 +531,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, SandboxFlagsSetForChildFrames) {
~blink::WebSandboxFlags::kOrigin,
root->child_at(2)->effective_sandbox_flags());
// Sandboxed frames should set a unique origin unless they have the
// "allow-same-origin" directive.
EXPECT_EQ("null", root->child_at(0)->current_origin().Serialize());
EXPECT_EQ("null", root->child_at(1)->current_origin().Serialize());
@@ -685,8 +685,8 @@ IN_PROC_BROWSER_TEST_F(CrossProcessFrameTreeBrowserTest,
GURL data_url("data:text/html,foo");
NavigateFrameToURL(root->child_at(1), data_url);
// Navigating to a data URL should set a unique origin. This is represented
// as "null" per RFC 6454.
EXPECT_EQ(root->child_at(1)->current_origin().Serialize(), "null");
}
« no previous file with comments | « content/browser/child_process_security_policy_impl.cc ('k') | content/browser/frame_host/navigation_request.cc » ('j') | no next file with comments »
@@ -274,10 +274,10 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, OriginSetOnNavigation) {
GURL data_url("data:text/html,foo");
EXPECT_TRUE(NavigateToURL(shell(), data_url));
- // Navigating to a data URL should set a unique origin. This is represented
- // as "null" per RFC 6454.
+ // Navigating to a data URL should set a unique opaque origin. This is
+ // represented as "null" per RFC 6454.
EXPECT_EQ("null", root->current_origin().Serialize());
@@ -531,7 +531,7 @@ IN_PROC_BROWSER_TEST_F(FrameTreeBrowserTest, SandboxFlagsSetForChildFrames) {
~blink::WebSandboxFlags::kOrigin,
root->child_at(2)->effective_sandbox_flags());
- // Sandboxed frames should set a unique origin unless they have the
+ // Sandboxed frames should set a unique opaque origin unless they have the
// "allow-same-origin" directive.
EXPECT_EQ("null", root->child_at(0)->current_origin().Serialize());
@@ -685,8 +685,8 @@ IN_PROC_BROWSER_TEST_F(CrossProcessFrameTreeBrowserTest,
GURL data_url("data:text/html,foo");
NavigateFrameToURL(root->child_at(1), data_url);
- // Navigating to a data URL should set a unique origin. This is represented
- // as "null" per RFC 6454.
+ // Navigating to a data URL should set a unique opaque origin. This is
+ // represented as "null" per RFC 6454.
EXPECT_EQ(root->child_at(1)->current_origin().Serialize(), "null");
}

Powered by Google App Engine
This is Rietveld 408576698